package de.hsrm.cs.javaee8.statelessmaven.web;

import javax.annotation.PostConstruct;
import javax.ejb.EJB;
import javax.enterprise.context.RequestScoped;
import javax.inject.Named;

import de.hsrm.cs.javaee7.statelessmaven.ejb.GeometricModelLocal;

/**Backing bean for the sample JSF page: has properties for the side lengths a, b, c of a cuboid,
 * and volume/surface can be calculated. 
 * 
 * @author Wolfgang Knauf
 *
 */
@Named(value="geometricModelHandler")
@RequestScoped
public class GeometricModelHandler
{

  /**Local interface for Bean @see GeometricModelBean is injected by the server.
   */
  @EJB
  private GeometricModelLocal geometricModelLocal;

  private double dblA = 0;
  private double dblB = 0;
  private double dblC = 0;
  
  /**Testing code: writes a debug message when the class is constructed
   * 
   */
  @PostConstruct
  public void postContruct() 
  {
    System.out.println("GeometricModelHandler.postConstruct");
  }
  
  /**Get side a
   * 
   * @return Side a
   */
  public double getA()
  {
    return dblA;
  }
  
  /**Set side a
   * 
   * @param dblA side a
   */
  public void setA(double dblA)
  {
    this.dblA = dblA;
  }

  /**Get side b
   * 
   * @return Side b
   */
  public double getB()
  {
    return dblB;
  }
  
  /**Set side b
   * 
   * @param dblB side b
   */
  public void setB(double dblB)
  {
    this.dblB = dblB;
  }

  /**Get side c
   * 
   * @return Side c
   */
  public double getC()
  {
    return dblC;
  }

  /**Set side c
   * 
   * @param dblC side c
   */
  public void setC(double dblC)
  {
    this.dblC = dblC;
  }
  
  private double dblSurface = 0;
  private double dblVolume = 0;
  
  /**Get volumne (only valid after "calculate" was called)
   * 
   * @return Volume
   */
  public double getVolume()
  {
    return this.dblVolume;
  }
  
  /**Get surface (only valid after "calculate" was called)
   * 
   * @return Surface
   */
  public double getSurface()
  {
    return this.dblSurface;
  } 
  
  /**Calculates volumne and surface.
   * This method is called in button click of a JSF page.  
   * 
   * @return Navigation result
   */
  public String calculate()
  {
    //Calculate the values and store in member variables:
    //this.dblVolume = this.dblA * this.dblB * this.dblC;
    //this.dblSurface = 2 * (this.dblA * this.dblB) + 2 * (this.dblA * this.dblC) + 2 * (this.dblB * this.dblC);
    this.dblVolume = this.geometricModelLocal.computeCuboidVolume(this.dblA, this.dblB, this.dblC);
    this.dblSurface = this.geometricModelLocal.computeCuboidSurface(this.dblA, this.dblB, this.dblC);
   
    //Return value does not matter, because this simple sample has no navigation rules.
    return null;
  } 
  
  /**Create a debugging string
   * 
   * @return Debugging string with all information.
   */
  @Override
  public String toString()
  {
    return "a: " + this.dblA + ", b: " + this.dblB + ", c: " + this.dblC + ", volume: " + this.dblVolume + ", surface: " + this.dblSurface;
  }
}
